==> haskell-vector-sized-1.6.1-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-3KNMfpCmIKc193zu1jJIJg
key:                  vector-sized-1.6.1-3KNMfpCmIKc193zu1jJIJg
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  ede948dcc3b31952395749f15416d47e
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-3KNMfpCmIKc193zu1jJIJg
depends:
    adjunctions-4.4.3-LGSeqauPscb1KCb2VxcjNK base-4.17.2.1
    binary-0.8.9.1 comonad-5.0.9-7ovkNyXx8QjFNTcyXoMDqs deepseq-1.4.8.0
    distributive-0.6.2.1-FmGbMm7Zg0XKdpzWDlcElj
    finite-typelits-0.2.1.0-LRghF2a3mS3HAD9MPNT7nM
    hashable-1.4.4.0-2lvxXC6j7O5I2GR31C0SqX
    indexed-list-literals-0.2.1.3-9X8auLtFCBu7rtYhzjI8NO
    indexed-traversable-0.1.4-LyeF3yLPY26FCcc6uHtQva
    primitive-0.9.1.0-3qHntBOAe4Y4he61Fs3OAc
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-sized-1.6.1-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-4N6toQYZ1ngEuzHkb8n8OB
key:                  vector-sized-1.6.1-4N6toQYZ1ngEuzHkb8n8OB
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  a38df35233e3e4776b3d5cd2e877c95f
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-4N6toQYZ1ngEuzHkb8n8OB
depends:
    adjunctions-4.4.3-3ptdmr6wH2375AWPuyA8Vx base-4.17.2.1
    binary-0.8.9.1 comonad-5.0.9-BwSgGbEK8HU1NmS9v2nuKD deepseq-1.4.8.0
    distributive-0.6.2.1-kL6RPisRvM6LT5mb4Nywn
    finite-typelits-0.2.1.0-7aI2aDOUCnmK4Yi5yJajq4
    hashable-1.4.4.0-AFqmlTE0BBaCoTGEV5znl2
    indexed-list-literals-0.2.1.3-KjtBuyylfG2BDKuvHiRPLu
    indexed-traversable-0.1.4-C3JpN7YDWmy6ZJ7hWVfhAu
    primitive-0.9.1.0-2rF1KRuV9tjItame9gIzcT
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
